@@ -289,9 +289,10 @@ sub _listen {
   }
 
   # Friendly message
+  return if $self->silent;
   $self->app->log->info("Server listening ($listen)");
   $listen =~ s/^(https?\:\/\/)\*/${1}127.0.0.1/i;
-  print "Server available at $listen.\n" unless $self->silent;
+  print "Server available at $listen.\n";
 }
 
 sub _read {
